@@ -2,21 +2,16 @@
 # patch for svgalib-1.4.?.tar.gz with gcc-3.3 and higher
 # execute it in your svgalib-1.4.? directory
 
-if cd src 2> /dev/null
+if cd src 2> /dev/null && test -f vga.c && test -f driver.h
 then
   cat vga.c | sed -e 's/mmt.##x/mmt.x/' > vga_.c && mv -f vga_.c vga.c
   cat driver.h | sed -e 's/MAX_REGS 5000/MAX_REGS 6460/' > driver_.h && mv -f driver_.h driver.h
+  cd ../demos 2> /dev/null && test -f lineart.c && cat lineart.c | sed -e 's/\("Usage:linp .*[^\\]\)$/\1\\/' > lineart_.c && mv -f lineart_.c lineart.c
   cd ..
+  echo "Finished"
 else
   echo "Cannot change to src"
   echo "Call this script from your svgalib-? directory"
+  exit 1
 fi
-if cd demos 2> /dev/null
-then
-  cat lineart.c | sed -e 's/\("Usage:linp .*[^\\]\)$/\1\\/' > lineart_.c && mv -f lineart_.c lineart.c
-  cd ..
-else
-  echo "Cannot change to demos"
-  echo "Call this script from your svgalib-? directory"
-fi
-echo "Finished"
+exit 0
